@@ -2,7 +2,7 @@
  *  Hamlib AOR backend - main file
  *  Copyright (c) 2000-2005 by Stephane Fillod
  *
- *	$Id: aor.c,v 1.39 2005/04/21 20:19:41 fillods Exp $
+ *	$Id: aor.c,v 1.42 2006/11/02 15:19:58 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -75,7 +75,7 @@ static int aor_transaction(RIG *rig, const char *cmd, int cmd_len, char *data, i
 {
 	int retval;
 	struct rig_state *rs;
-	unsigned char ackbuf[BUFSZ];
+	char ackbuf[BUFSZ];
 	int ack_len;
 
 	rs = &rig->state;
@@ -158,7 +158,7 @@ static int format_freq(char *buf, freq_t freq)
  */
 int aor_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-	unsigned char freqbuf[BUFSZ];
+	char freqbuf[BUFSZ];
 	int freq_len;
 
 	freq_len = format_freq(freqbuf, freq);
@@ -176,7 +176,7 @@ int aor_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
 	char *rfp;
 	int freq_len, retval;
-	unsigned char freqbuf[BUFSZ];
+	char freqbuf[BUFSZ];
 
 	retval = aor_transaction (rig, "RX" EOM, 3, freqbuf, &freq_len);
 	if (retval != RIG_OK)
@@ -227,7 +227,7 @@ int aor_set_vfo(RIG *rig, vfo_t vfo)
 int aor_get_vfo(RIG *rig, vfo_t *vfo)
 {
 	int vfo_len, retval;
-	unsigned char vfobuf[BUFSZ];
+	char vfobuf[BUFSZ];
 
 	retval = aor_transaction (rig, "RX" EOM, 3, vfobuf, &vfo_len);
 	if (retval != RIG_OK)
@@ -306,16 +306,35 @@ int format8k_mode(RIG *rig, char *buf, rmode_t mode, pbwidth_t width)
 int aor_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
 	struct aor_priv_caps *priv = (struct aor_priv_caps*)rig->caps->priv;
-	unsigned char mdbuf[BUFSZ];
-	int mdbuf_len, retval;
+	char mdbuf[BUFSZ];
+	char mdbuf2[BUFSZ] = "";
+	int mdbuf_len, mdbuf2_len, retval;
 
 	mdbuf_len = priv->format_mode(rig, mdbuf, mode, width);
 
 	strcpy(mdbuf+mdbuf_len, EOM);
 	mdbuf_len += strlen(EOM);
 
-	retval = aor_transaction (rig, mdbuf, mdbuf_len, NULL, NULL);
+	switch (rig->caps->rig_model) {
+	    case RIG_MODEL_AR5000:
+	    case RIG_MODEL_AR5000A:
+		strncpy(mdbuf2, mdbuf, 3);      /* Extract first 'MD' part */
+		mdbuf2_len = strlen(mdbuf2);
+		strcpy(mdbuf2+mdbuf2_len, EOM); /* Add delimiter */
+		mdbuf2_len = strlen(mdbuf2);
 
+		retval = aor_transaction (rig, mdbuf2, mdbuf2_len, NULL, NULL);
+
+		strncpy(mdbuf2, mdbuf + 4, 3); /* Extract first 'BW' part */
+		mdbuf2_len = strlen(mdbuf2);
+
+		retval = aor_transaction (rig, mdbuf2, mdbuf2_len, NULL, NULL);
+		break;
+
+	    default:
+		retval = aor_transaction (rig, mdbuf, mdbuf_len, NULL, NULL);
+	}
+	
 	return retval;
 }
 
@@ -364,8 +383,8 @@ int parse8k_aor_mode(RIG *rig, char aormode, char aorwidth, rmode_t *mode, pbwid
 int aor_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
 	struct aor_priv_caps *priv = (struct aor_priv_caps*)rig->caps->priv;
-	unsigned char ackbuf[BUFSZ], *mdp;
-	unsigned char ackbuf2[BUFSZ], *mdp2;
+	char ackbuf[BUFSZ], *mdp;
+	char ackbuf2[BUFSZ], *mdp2;
 	int ack_len, ack2_len, retval;
 
 
@@ -384,7 +403,8 @@ int aor_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 		return -RIG_EPROTO;
 	}
 
-	if (rig->caps->rig_model == RIG_MODEL_AR5000) {
+	if (rig->caps->rig_model == RIG_MODEL_AR5000 ||
+	    rig->caps->rig_model == RIG_MODEL_AR5000A) {
 		retval = aor_transaction (rig, "BW" EOM, 3, ackbuf2, &ack2_len);
 		if (retval != RIG_OK)
 			return retval;
@@ -404,7 +424,7 @@ int aor_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
  */
 int aor_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
 {
-	unsigned char tsbuf[BUFSZ];
+	char tsbuf[BUFSZ];
 	int ts_len;
 
 	/*
@@ -424,7 +444,7 @@ int aor_set_ts(RIG *rig, vfo_t vfo, shortfreq_t ts)
 int aor_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
 	struct rig_state *rs;
-	unsigned char lvlbuf[BUFSZ];
+	char lvlbuf[BUFSZ];
 	int lvl_len;
 	unsigned i;
 	int agc;
@@ -442,14 +462,14 @@ int aor_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 				break;
 			}
 		}
-		/* should be catched by the front end */
-		if (i>=MAXDBLSTSIZ || RIG_IS_DBLST_END(rs->attenuator[i]))
+		/* should be caught by the front end */
+		if ((val.i != 0) & (i>=MAXDBLSTSIZ || RIG_IS_DBLST_END(rs->attenuator[i])) )
 			return -RIG_EINVAL;
 
 		lvl_len = sprintf(lvlbuf, "AT%u" EOM, att);
 		break;
 		}
-	case RIG_LEVEL_AGC:	/* AR5000 */
+	case RIG_LEVEL_AGC:	/* AR5000 & AR5000A */
 		switch(val.i) {
 		case RIG_AGC_FAST: agc = '0'; break;
 		case RIG_AGC_MEDIUM: agc = '1'; break;
@@ -475,7 +495,7 @@ int aor_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
 	struct rig_state *rs;
-	unsigned char lvlbuf[BUFSZ],ackbuf[BUFSZ];
+	char lvlbuf[BUFSZ],ackbuf[BUFSZ];
 	int lvl_len, ack_len, retval;
 
 	rs = &rig->state;
@@ -487,7 +507,7 @@ int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 	case RIG_LEVEL_ATT:
 		lvl_len = sprintf(lvlbuf, "AT" EOM);
 		break;
-	case RIG_LEVEL_AGC:	/* AR5000 */
+	case RIG_LEVEL_AGC:	/* AR5000 & AR5000A */
 		lvl_len = sprintf(lvlbuf, "AC" EOM);
 		break;
 	default:
@@ -528,13 +548,32 @@ int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 	case RIG_LEVEL_AGC:
 		if (ack_len < 3 || ackbuf[0] != 'A' || ackbuf[1] != 'C')
 			return -RIG_EPROTO;
-		switch(ackbuf[3]) {
-		case '0': val->i = RIG_AGC_FAST; break;
-		case '1': val->i = RIG_AGC_MEDIUM; break;
-		case '2': val->i = RIG_AGC_SLOW; break;
-		case 'F':
-		default: val->i = RIG_AGC_OFF;
+
+		if (rig->caps->rig_model == RIG_MODEL_AR5000 ||
+		    rig->caps->rig_model == RIG_MODEL_AR5000A) {
+                    /* AR5000A requires switching to be made on
+		       3rd returned character. SM6PPS */
+
+		    switch(ackbuf[2]) {
+			case '0': val->i = RIG_AGC_FAST; break;
+			case '1': val->i = RIG_AGC_MEDIUM; break;
+			case '2': val->i = RIG_AGC_SLOW; break;
+			case 'F':
+			default: val->i = RIG_AGC_OFF;
+		    }
+		} else {
+                    /* Left the switching on 4th position in case
+		       models other than AR5000(A) use this. SM6PPS */
+
+		    switch(ackbuf[3]) {
+			case '0': val->i = RIG_AGC_FAST; break;
+			case '1': val->i = RIG_AGC_MEDIUM; break;
+			case '2': val->i = RIG_AGC_SLOW; break;
+			case 'F':
+			default: val->i = RIG_AGC_OFF;
+		    }
 		}
+
 		break;
 
 	default:
@@ -551,7 +590,7 @@ int aor_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
  */
 int aor_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
-	unsigned char ackbuf[BUFSZ];
+	char ackbuf[BUFSZ];
 	int  ack_len, retval;
 
 	retval = aor_transaction (rig, "LM" EOM, 3, ackbuf, &ack_len);
@@ -610,7 +649,7 @@ int aor_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 int aor_set_mem(RIG *rig, vfo_t vfo, int ch)
 {
 	struct aor_priv_caps *priv = (struct aor_priv_caps*)rig->caps->priv;
-	unsigned char membuf[BUFSZ];
+	char membuf[BUFSZ];
 	int mem_len;
 	int mem_num;
 	char bank_base;
@@ -642,7 +681,7 @@ int aor_get_mem(RIG *rig, vfo_t vfo, int *ch)
 {
 	struct aor_priv_caps *priv = (struct aor_priv_caps*)rig->caps->priv;
 	int mem_len, retval;
-	unsigned char membuf[BUFSZ];
+	char membuf[BUFSZ];
 
 	retval = aor_transaction (rig, "MR" EOM, 3, membuf, &mem_len);
 	if (retval != RIG_OK)
@@ -673,7 +712,7 @@ int aor_get_mem(RIG *rig, vfo_t vfo, int *ch)
 int aor_set_bank(RIG *rig, vfo_t vfo, int bank)
 {
 	struct aor_priv_caps *priv = (struct aor_priv_caps*)rig->caps->priv;
-	unsigned char membuf[BUFSZ];
+	char membuf[BUFSZ];
 	int mem_len;
 
 	mem_len = sprintf(membuf,"MR%c" EOM, (bank%10) + (bank<10 ? 
@@ -713,6 +752,7 @@ static int parse_chan_line(RIG *rig, channel_t *chan, char *basep, const channel
 	struct aor_priv_caps *priv = (struct aor_priv_caps*)rig->caps->priv;
 	int retval;
 	char *tagp;
+        int ts;
 
 	/* 
 	 * search for attribute tags in the line.
@@ -780,7 +820,8 @@ static int parse_chan_line(RIG *rig, channel_t *chan, char *basep, const channel
 					__FUNCTION__, basep);
 			return -RIG_EPROTO;
 		}
-		sscanf(tagp+2,"%d", (int*)&chan->tuning_step);
+                ts = chan->tuning_step;
+		sscanf(tagp+2,"%d", &ts);
 	}
 
 
@@ -1047,6 +1088,7 @@ DECLARE_INITRIG_BACKEND(aor)
 	rig_register(&ar3000a_caps);
 	rig_register(&ar7030_caps);
 	rig_register(&ar3030_caps);
+	rig_register(&ar5000a_caps);
 
 	return RIG_OK;
 }
