@@ -1,8 +1,8 @@
 /*
  *  Hamlib CI-V backend - defines for the ICOM "CI-V" interface.
- *  Copyright (c) 2000-2002 by Stephane Fillod
+ *  Copyright (c) 2000-2004 by Stephane Fillod
  *
- *		$Id: icom_defs.h,v 1.14 2002/03/10 23:39:35 fillods Exp $
+ *		$Id: icom_defs.h,v 1.19 2006/09/22 19:55:59 n0nb Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -27,7 +27,7 @@
  *  CI-V frame codes
  */
 #define PR		0xfe		/* Preamble code */
-#define CTRLID	0xe0		/* Controllers's default address */
+#define CTRLID		0xe0		/* Controllers's default address */
 #define BCASTID	0x00		/* Broadcast address */
 #define FI		0xfd		/* End of message code */
 #define ACK		0xfb		/* OK code */
@@ -49,15 +49,23 @@
 
 /*
  * Cn controller commands
+ *
+
+ 	Most radios have 2 or 3 recieve passbands available.  Where only 2 are available they
+	are selected by 01 for wide and 02 for narrow  Actual bandwidth is determined by the filters
+	installed.  With the newer DSP rigs there are 3 presets 01 = wide 02 = middle and 03 = narrow. 
+	Acutally you can set change any of these presets to any thing you want.
+
  * Notes:
- * 1. When wide or normal op available: add "00" for wide, "01" normal
+ * The following only applies to IC-706.
+ * 1.  When wide or normal op available: add "00" for wide, "01" normal
  * 	  Normal or narrow op: add "00" for normal, "01" for narrow
  * 	  Wide, normal or narrow op: add "00" for wide, "01" normal, "02" narrow
  * 2. Memory channel number 1A=0100/1b=0101, 2A=0102/2b=0103,
  * 	  3A=0104/3b=0105, C1=0106, C2=0107
  */
-#define C_SND_FREQ	0x00		/* Send frequency data */
-#define C_SND_MODE	0x01		/* Send mode data, Sc */
+#define C_SND_FREQ	0x00		/* Send frequency data  trancieve mode does not ack*/
+#define C_SND_MODE	0x01		/* Send mode data, Sc  for trancieve mode does not ack */
 #define C_RD_BAND	0x02		/* Read band edge frequencies */
 #define C_RD_FREQ	0x03		/* Read display frequency */
 #define C_RD_MODE	0x04		/* Read display mode */
@@ -68,13 +76,13 @@
 #define C_WR_MEM	0x09		/* Write memory */
 #define C_MEM2VFO	0x0a		/* Memory to VFO */
 #define C_CLR_MEM	0x0b		/* Memory clear */
-#define C_RD_OFFS	0x0c		/* Read duplex offset frequency */
+#define C_RD_OFFS	0x0c		/* Read duplex offset frequency; default changes with HF/6M/2M */
 #define C_SET_OFFS	0x0d		/* Set duplex offset frequency */
 #define C_CTL_SCAN	0x0e		/* Control scan, Sc */
-#define C_CTL_SPLT	0x0f		/* Control split, Sc */
+#define C_CTL_SPLT	0x0f		/* Control split, and duplex mode Sc */
 #define C_SET_TS	0x10		/* Set tuning step, Sc */
-#define C_CTL_ATT	0x11		/* Set attenuator, Sc */
-#define C_CTL_ANT	0x12		/* Set antenna, Sc */
+#define C_CTL_ATT	0x11		/* Set/get attenuator, Sc */
+#define C_CTL_ANT	0x12		/* Set/get antenna, Sc */
 #define C_CTL_ANN	0x13		/* Control announce (speech synth.), Sc */
 #define C_CTL_LVL	0x14		/* Set AF/RF/squelch, Sc */
 #define C_RD_SQSM	0x15		/* Read squelch condiction/S-meter level, Sc */
@@ -82,7 +90,7 @@
 #define C_SND_CW	0x17		/* Send CW message */
 #define C_SET_PWR	0x18		/* Set Power ON/OFF, Sc */
 #define C_RD_TRXID	0x19		/* Read transceiver ID code */
-#define C_CTL_MEM	0x1a		/* Misc memory/bank functions, Sc */
+#define C_CTL_MEM	0x1a		/* Misc memory/bank/rig control functions, Sc */
 #define C_SET_TONE	0x1b		/* Set tone frequency */
 #define C_CTL_PTT	0x1c		/* Control Transmit On/Off, Sc */
 #define C_CTL_MISC	0x7f		/* Miscellaneous control, Sc */
@@ -102,6 +110,11 @@
 #define S_RTTY	0x04		/* Set to RTTY */
 #define S_FM	0x05		/* Set to FM */
 #define S_WFM	0x06		/* Set to Wide FM */
+#define S_CWR	0x07		/* Set to CW Reverse */
+#define S_RTTYR	0x08		/* Set to RTTY Reverse */
+#define S_AMS	0x11		/* Set to AMS */
+#define S_PSK	0x12		/* 7800 PSK USB */
+#define S_PSKR	0x13		/* 7800 PSK LSB */
 
 #define S_R7000_SSB	0x05	/* Set to SSB on R-7000 */
 #define PD_WIDE		0x01	/* Wide */
@@ -130,17 +143,20 @@
 /*
  * Scan control (C_CTL_SCAN) subcommands
  */
-#define S_SCAN_STOP		0x00		/* Stop scan/window scan */
+#define S_SCAN_STOP	0x00		/* Stop scan/window scan */
 #define S_SCAN_START	0x01		/* Programmed/Memory scan */
-#define S_SCAN_PROG		0x02		/* Programmed scan */
+#define S_SCAN_PROG	0x02		/* Programmed scan */
 #define S_SCAN_DELTA	0x03		/* Delta-f scan */
 #define S_SCAN_WRITE	0x04		/* auto memory-write scan */
 #define S_SCAN_FPROG	0x12		/* Fine programmed scan */
 #define S_SCAN_FDELTA	0x13		/* Fine delta-f scan */
-#define S_SCAN_MEM2		0x22		/* Memory scan */
+#define S_SCAN_MEM2	0x22		/* Memory scan */
 #define S_SCAN_SLCTN	0x23		/* Selected number memory scan */
 #define S_SCAN_SLCTM	0x24		/* Selected mode memory scan */
-#define S_SCAN_PRIO		0x42		/* Priority / window scan */
+#define S_SCAN_PRIO	0x42		/* Priority / window scan */
+#define S_SCAN_NSLCT	0xB0        /* Set as non select channel */
+#define S_SCAN_SLCT	0xB1        /* Set as select channel */
+#define S_SCAN_SL_NUM	0xB2		/* select programed mem scan 7800 only */
 #define S_SCAN_RSMOFF   0xD0        /* Set scan resume OFF */
 #define S_SCAN_RSMON    0xD3        /* Set scan resume ON */
 
@@ -157,7 +173,7 @@
 /*
  * Set Attenuator (C_CTL_ATT) subcommands
  */
-#define S_ATT_RD	0x00		/* Without subcommand, reads out setting */
+#define S_ATT_RD	-1		/* Without subcommand, reads out setting */
 #define S_ATT_OFF	0x00		/* Off */
 #define S_ATT_6dB	0x06		/* 6 dB, IC-756Pro */
 #define S_ATT_10dB	0x10		/* 10 dB */
@@ -176,7 +192,7 @@
 /*
  * Set antenna (C_SET_ANT) subcommands
  */
-#define S_ANT_RD	0x00		/* Without subcommand, reads out setting */
+#define S_ANT_RD	-1		/* Without subcommand, reads out setting */
 #define S_ANT1		0x00		/* Antenna 1 */
 #define S_ANT2		0x01		/* Antenna 2 */
 
@@ -197,29 +213,33 @@
 #define S_LVL_APF		0x05		/* APF level setting */
 #define S_LVL_NR		0x06		/* NR level setting */
 #define S_LVL_PBTIN		0x07		/* Twin PBT setting (inside) */
-#define S_LVL_PBTOUT	0x08		/* Twin PBT setting (outside) */
-#define S_LVL_CWPITCH	0x09		/* CW pitch setting */
-#define S_LVL_RFPOWER	0x0a		/* RF power setting */
-#define S_LVL_MICGAIN	0x0b		/* MIC gain setting */
-#define S_LVL_KEYSPD	0x0c		/* Key Speed setting */
-#define S_LVL_NOTCHF	0x0d		/* Notch freq. setting */
+#define S_LVL_PBTOUT		0x08		/* Twin PBT setting (outside) */
+#define S_LVL_CWPITCH		0x09		/* CW pitch setting */
+#define S_LVL_RFPOWER		0x0a		/* RF power setting */
+#define S_LVL_MICGAIN		0x0b		/* MIC gain setting */
+#define S_LVL_KEYSPD		0x0c		/* Key Speed setting */
+#define S_LVL_NOTCHF		0x0d		/* Notch freq. setting */
 #define S_LVL_COMP		0x0e		/* Compressor level setting */
-#define S_LVL_BKINDL	0x0f		/* BKin delay setting */
-#define S_LVL_BALANCE	0x10		/* Balance setting (Dual watch) */
+#define S_LVL_BKINDL		0x0f		/* BKin delay setting */
+#define S_LVL_BALANCE		0x10		/* Balance setting (Dual watch) */
 
 /*
- * Read squelch condition/S-meter level (C_RD_SQSM) subcommands
+ * Read squelch condition/S-meter level/other meter levels (C_RD_SQSM) subcommands
  */
 #define S_SQL	0x01		/* Read squelch condition */
 #define S_SML	0x02		/* Read S-meter level */
+#define S_RFML	0x11		/* Read RF-meter level */
+#define S_SWR	0x12		/* Read SWR-meter level */
+#define S_ALC	0x13		/* Read ALC-meter level */
+#define S_CMP	0x14		/* Read COMP-meter level */
 
 /*
- * Function settings (C_CTL_FUNC) subcommands
+ * Function settings (C_CTL_FUNC) subcommands  Set and Read
  */
 #define S_FUNC_PAMP	0x02		/* Preamp setting */
 #define S_FUNC_AGCOFF	0x10		/* IC-R8500 only */
 #define S_FUNC_AGCON 	0x11		/* IC-R8500 only */
-#define S_FUNC_AGC	0x12		/* AGC setting */
+#define S_FUNC_AGC	0x12		/* AGC setting presets: the dsp models allow these to be modified */
 #define S_FUNC_NBOFF	0x20		/* IC-R8500 only */
 #define S_FUNC_NBON	0x21		/* IC-R8500 only */
 #define S_FUNC_NB	0x22		/* NB setting */
@@ -235,13 +255,12 @@
 #define S_FUNC_VOX	0x46		/* VOX setting */
 #define S_FUNC_BKIN	0x47		/* BK-IN setting */
 #define S_FUNC_MN	0x48		/* Manual notch setting */
-#define S_FUNC_RNF	0x49		/* RTTY Filter Notch setting */
-#define S_FUNC_AFC  0x4A        /* Auto Frequency Control (AFC) setting */
-
-/*
- * Transceiver ID (C_RD_TRXID) subcommands
- */
-#define S_TRXID	0x00		/* Read transceiver ID code */
+#define S_FUNC_RF	0x49		/* RTTY Filter setting */
+#define S_FUNC_AFC  	0x4A        /* Auto Frequency Control (AFC) setting */
+#define S_FUNC_DTCS	0x4B		/*DTCS tone code squelch setting*/
+#define S_FUNC_VSC	0x4C		/* voice squelch control useful for scanning*/
+#define S_FUNC_TW_PK	0x4F		/* RTTY Twin Peak filter 0= off 1 = on */
+#define S_FUNC_DIAL_LK	0x50		/* Dial lock */
 
 /*
  * Set Power On/Off (C_SET_PWR) subcommands
@@ -252,14 +271,25 @@
 /*
  * Transmit control (C_CTL_PTT) subcommands
  */
-#define S_PTT_ON	0x00		/* no documentation, not tested! */
-#define S_PTT_OFF	0x01		/* please confirm (IC-756Pro, IC-746) --SF */
+#define S_PTT		0x00
+#define S_ANT_TUN	0x01	/* Auto tuner 0=OFF, 1 = ON, 2=Start Tuning */
 
 /*
- * Memory contents (C_CTL_MEM) subcommands
+ * Misc contents (C_CTL_MEM) subcommands applies to newer rigs.
  */
-#define S_MEM_CNTNT	0x00
+#define S_MEM_CNTNT		0x00	/* Memory content 2 bigendian */
+#define S_MEM_BAND_REG		0x01	/* band stacking register */
+#define S_MEM_FILT_WDTH		0x03	/* current passband filter width */
+#define S_MEM_PARM		0x05	/* rig parameters; extended parm # + param value:  should be coded */
+					/* in the rig files because they are different for each rig */
+#define S_MEM_DATA_MODE		0x06	/* data mode */
+#define S_MEM_TX_PB		0x07	/* SSB tx passband */
+#define S_MEM_FLTR_SHAPE	0x08	/* DSP filter shape 0=sharp 1=soft */
+
+					/* Icr75c */
 #define S_MEM_CNTNT_SLCT	0x01
+#define S_MEM_FLT_SLCT		0x01
+#define S_MEM_MODE_SLCT		0x02
                                     /* For IC-910H rig. */
 #define S_MEM_RDWR_MEM      0x00    /* Read/write memory channel */
 #define S_MEM_SATMEM        0x01    /* Satellite memory */
@@ -271,14 +301,16 @@
 #define S_MEM_SATMODE       0x07    /* Satellite mode (on/off) */
 #define S_MEM_BANDSCOPE     0x08    /* Simple bandscope (on/off) */
 
+
 /*
  * Tone control (C_SET_TONE) subcommands
  */
-#define S_TONE_RPTR	0x00		/* Tone frequency setting for repeater user */
+#define S_TONE_RPTR	0x00		/* Tone frequency setting for repeater receive */
 #define S_TONE_SQL	0x01		/* Tone frequency setting for squelch */
+#define S_TONE_DTCS	0x02		/* DTCS code and polarity for squelch */
 
 /*
- * C_RD_TRXID
+ * Transceiver ID (C_RD_TRXID) subcommands
  */
 #define S_RD_TRXID 0x00
 
@@ -302,4 +334,29 @@
 #define S_OPTO_SCON 	0x0f
 #define S_OPTO_SCOFF 	0x10
 
+/*
+ * C_CTL_MODE	Misc CI-V Mode settings
+ */
+#define S_PRM_BEEP		0x02
+#define S_PRM_CWPITCH	0x10
+#define S_PRM_LANG		0x15
+#define S_PRM_BACKLT	0x21
+#define S_PRM_SLEEP		0x32
+#define S_PRM_SLPTM		0x33
+#define S_PRM_TIME		0x27
+
+/*
+ * Tokens for Extra Level and Parameters common to multiple rigs.  Use token # > 99.  Defined here so they
+ * will be available in ICOM name space. They have different internal commands primarily in dsp rigs.  These
+ * tokens are used ext_lvl and ext_parm funtions in the individual rig files.
+ * Extra parameters which are rig specific should be coded in the individual rig files and token #s < 100.
+ */
+ 
+#define TOKEN_BACKEND(t) (t)
+
+#define TOK_RTTY_FLTR TOKEN_BACKEND(100)
+#define TOK_SSBBASS TOKEN_BACKEND(101)
+#define TOK_SQLCTRL TOKEN_BACKEND(102)
+
+
 #endif /* _ICOM_DEFS_H */
