@@ -2,7 +2,7 @@
  *  Hamlib Interface - API header
  *  Copyright (c) 2000-2005 by Stephane Fillod and Frank Singleton
  *
- *	$Id: rig.h,v 1.110 2006/01/15 14:23:16 fillods Exp $
+ *	$Id: rig.h,v 1.121 2007/02/28 08:52:49 mardigras Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -20,6 +20,7 @@
  *
  */
 
+
 #ifndef _RIG_H
 #define _RIG_H 1
 
@@ -28,8 +29,12 @@
 
 #include <hamlib/riglist.h>	/* list in another file to not mess up w/ this one */
 
+/**
+ * \addtogroup rig
+ * @{
+ */
+
 /*! \file rig.h
- *  \ingroup rig
  *  \brief Hamlib rig data structures.
  *
  *  This file contains the data structures and definitions for the Hamlib rig API.
@@ -75,24 +80,24 @@ extern HAMLIB_EXPORT_VAR(const char) hamlib_copyright[];
  * Error codes that can be returned by the Hamlib functions
  */
 enum rig_errcode_e {
-	RIG_OK=0,		/*<! No error, operation completed sucessfully */
-	RIG_EINVAL,		/*<! invalid parameter */
-	RIG_ECONF,		/*<! invalid configuration (serial,..) */
-	RIG_ENOMEM,		/*<! memory shortage */
-	RIG_ENIMPL,		/*<! function not implemented, but will be */
-	RIG_ETIMEOUT,		/*<! communication timed out */
-	RIG_EIO,		/*<! IO error, including open failed */
-	RIG_EINTERNAL,		/*<! Internal Hamlib error, huh! */
-	RIG_EPROTO,		/*<! Protocol error */
-	RIG_ERJCTED,		/*<! Command rejected by the rig */
-	RIG_ETRUNC,		/*<! Command performed, but arg truncated */
-	RIG_ENAVAIL,		/*<! function not available */
-	RIG_ENTARGET,		/*<! VFO not targetable */
-	RIG_BUSERROR,		/*<! Error talking on the bus */
-	RIG_BUSBUSY,		/*<! Collision on the bus */
-	RIG_EARG,		/*<! NULL RIG handle or any invalid pointer parameter in get arg */
-	RIG_EVFO,		/*<! Invalid VFO */
-	RIG_EDOM		/*<! Argument out of domain of func */
+	RIG_OK=0,		/*!< No error, operation completed sucessfully */
+	RIG_EINVAL,		/*!< invalid parameter */
+	RIG_ECONF,		/*!< invalid configuration (serial,..) */
+	RIG_ENOMEM,		/*!< memory shortage */
+	RIG_ENIMPL,		/*!< function not implemented, but will be */
+	RIG_ETIMEOUT,		/*!< communication timed out */
+	RIG_EIO,		/*!< IO error, including open failed */
+	RIG_EINTERNAL,		/*!< Internal Hamlib error, huh! */
+	RIG_EPROTO,		/*!< Protocol error */
+	RIG_ERJCTED,		/*!< Command rejected by the rig */
+	RIG_ETRUNC,		/*!< Command performed, but arg truncated */
+	RIG_ENAVAIL,		/*!< function not available */
+	RIG_ENTARGET,		/*!< VFO not targetable */
+	RIG_BUSERROR,		/*!< Error talking on the bus */
+	RIG_BUSBUSY,		/*!< Collision on the bus */
+	RIG_EARG,		/*!< NULL RIG handle or any invalid pointer parameter in get arg */
+	RIG_EVFO,		/*!< Invalid VFO */
+	RIG_EDOM		/*!< Argument out of domain of func */
 };
 
 /**
@@ -103,12 +108,12 @@ enum rig_errcode_e {
  * \sa rig_set_debug
  */
 enum rig_debug_level_e {
-  RIG_DEBUG_NONE = 0,		/*<! no bug reporting */
-  RIG_DEBUG_BUG,		/*<! serious bug */
-  RIG_DEBUG_ERR,		/*<! error case (e.g. protocol, memory allocation) */
-  RIG_DEBUG_WARN,		/*<! warning */
-  RIG_DEBUG_VERBOSE,		/*<! verbose */
-  RIG_DEBUG_TRACE		/*<! tracing */
+  RIG_DEBUG_NONE = 0,		/*!< no bug reporting */
+  RIG_DEBUG_BUG,		/*!< serious bug */
+  RIG_DEBUG_ERR,		/*!< error case (e.g. protocol, memory allocation) */
+  RIG_DEBUG_WARN,		/*!< warning */
+  RIG_DEBUG_VERBOSE,		/*!< verbose */
+  RIG_DEBUG_TRACE		/*!< tracing */
 };
 
 /* --------------- Rig capabilities -----------------*/
@@ -434,8 +439,8 @@ typedef enum {
 	RIG_OP_FROM_VFO =	(1<<2),	/*!< VFO->MEM */
 	RIG_OP_TO_VFO =		(1<<3),	/*!< MEM->VFO */
 	RIG_OP_MCL =		(1<<4),	/*!< Memory clear */
-	RIG_OP_UP =		(1<<5),	/*!< UP */
-	RIG_OP_DOWN =		(1<<6),	/*!< DOWN */
+	RIG_OP_UP =		(1<<5),	/*!< UP increment VFO freq by tuning step*/
+	RIG_OP_DOWN =		(1<<6),	/*!< DOWN decrement VFO freq by tuning step*/
 	RIG_OP_BAND_UP =	(1<<7),	/*!< Band UP */
 	RIG_OP_BAND_DOWN =	(1<<8),	/*!< Band DOWN */
 	RIG_OP_LEFT =		(1<<9),	/*!< LEFT */
@@ -467,13 +472,24 @@ typedef long token_t;
 
 #define RIG_CONF_END 0
 
-/*
- * strongly inspired from soundmedem. Thanks Thomas!
+/**
+ * \brief  parameter types
+ *
+ *   Used with configuration, parameter and extra-parm tables.
+ * 
+ *   Current internal implementation
+ *   NUMERIC: val.f or val.i
+ *   COMBO: val.i, starting from 0.  Points to a table of strings or asci stored values.
+ *   STRING: val.s or val.cs
+ *   CHECKBUTTON: val.i 0/1
  */
+
+/* strongly inspired from soundmedem. Thanks Thomas! */
+
 enum rig_conf_e {
 	RIG_CONF_STRING,	/*!<	String type */
 	RIG_CONF_COMBO,		/*!<	Combo type */
-	RIG_CONF_NUMERIC,	/*!<	Numeric type (integer or real) */
+	RIG_CONF_NUMERIC,	/*!<	Numeric type integer or real */
 	RIG_CONF_CHECKBUTTON	/*!<	on/off type */
 };
 
@@ -525,7 +541,9 @@ typedef int ant_t;
 #define RIG_ANT_3	RIG_ANT_N(2)
 #define RIG_ANT_4	RIG_ANT_N(3)
 
-
+/**
+ * \brief AGC delay settings
+ */
 /* TODO: kill me, and replace by real AGC delay */
 enum agc_level_e {
 	RIG_AGC_OFF = 0,
@@ -627,7 +645,7 @@ enum rig_parm_e {
 #define RIG_PARM_IS_FLOAT(l) ((l)&RIG_PARM_FLOAT_LIST)
 #define RIG_PARM_SET(l) ((l)&~RIG_PARM_READONLY_LIST)
 
-#define RIG_SETTING_MAX 64
+#define RIG_SETTING_MAX 32
 /**
  * \brief Setting
  *
@@ -664,7 +682,7 @@ enum rig_func_e {
 	RIG_FUNC_APF =     	(1<<11),/*!< Auto Passband Filter */
 	RIG_FUNC_MON =     	(1<<12),/*!< Monitor transmitted signal */
 	RIG_FUNC_MN =     	(1<<13),/*!< Manual Notch */
-	RIG_FUNC_RNF =     	(1<<14),/*!< RTTY Filter Notch */
+	RIG_FUNC_RF =     	(1<<14),/*!< RTTY Filter */
 	RIG_FUNC_ARO =     	(1<<15),/*!< Auto Repeater Offset */
 	RIG_FUNC_LOCK =     	(1<<16),/*!< Lock */
 	RIG_FUNC_MUTE =     	(1<<17),/*!< Mute */
@@ -712,7 +730,10 @@ typedef enum {
 	RIG_MODE_PKTFM =        (1<<12),/*!< Packet/Digital FM mode (dedicated port) */
 	RIG_MODE_ECSSUSB =      (1<<13),/*!< Exalted Carrier Single Sideband USB */
 	RIG_MODE_ECSSLSB =      (1<<14),/*!< Exalted Carrier Single Sideband LSB */
-	RIG_MODE_FAX =          (1<<15) /*!< Facsimile Mode */
+	RIG_MODE_FAX =          (1<<15),/*!< Facsimile Mode */
+	RIG_MODE_SAM =          (1<<16),/*!< Synchronous AM double sideband */
+	RIG_MODE_SAL =          (1<<17),/*!< Synchronous AM lower sideband */
+	RIG_MODE_SAH =          (1<<18) /*!< Synchronous AM upper (higher) sideband */
 
 } rmode_t;
 
@@ -818,6 +839,8 @@ struct filter_list {
  */
 #define RIG_CHFLAG_NONE	0
 #define RIG_CHFLAG_SKIP	(1<<0)
+/* DATA port mode flag */
+#define RIG_CHFLAG_DATA (1<<1)
 
 /**
  * \brief Extension attribute definition
@@ -1061,8 +1084,8 @@ struct rig_caps {
   gran_t level_gran[RIG_SETTING_MAX];	/*!< level granularity (i.e. steps) */
   gran_t parm_gran[RIG_SETTING_MAX];	/*!< parm granularity (i.e. steps) */
 
-  const struct confparams *extparms;	/*!< Extension parm list */
-  const struct confparams *extlevels;	/*!< Extension level list */
+  const struct confparams *extparms;	/*!< Extension parm list, \sa ext.c */
+  const struct confparams *extlevels;	/*!< Extension level list, \sa ext.c */
 
   const tone_t *ctcss_list;	/*!< CTCSS tones list, zero ended */
   const tone_t *dcs_list;	/*!< DCS code list, zero ended */
@@ -1081,7 +1104,7 @@ struct rig_caps {
   int transceive;	/*!< Supported transceive mode */
 
   int bank_qty;		/*!< Number of banks */
-  int chan_desc_sz;	/*!< Max lenght of memory channel name */
+  int chan_desc_sz;	/*!< Max length of memory channel name */
 
   chan_t chan_list[CHANLSTSIZ];	/*!< Channel list, zero ended */
 
@@ -1227,8 +1250,8 @@ struct rig_caps {
   int (*set_mem_all_cb) (RIG * rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_ptr_t);
   int (*get_mem_all_cb) (RIG * rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_ptr_t);
 
-  const char *clone_combo_set;	/*<! String describing key combination to enter load cloning mode */
-  const char *clone_combo_get;	/*<! String describing key combination to enter save cloning mode */
+  const char *clone_combo_set;	/*!< String describing key combination to enter load cloning mode */
+  const char *clone_combo_get;	/*!< String describing key combination to enter save cloning mode */
 };
 
 /**
@@ -1498,6 +1521,7 @@ extern HAMLIB_EXPORT(int) rig_get_ext_parm HAMLIB_PARAMS((RIG *rig, token_t toke
 extern HAMLIB_EXPORT(int) rig_ext_level_foreach HAMLIB_PARAMS((RIG *rig, int (*cfunc)(RIG*, const struct confparams *, rig_ptr_t), rig_ptr_t data));
 extern HAMLIB_EXPORT(int) rig_ext_parm_foreach HAMLIB_PARAMS((RIG *rig, int (*cfunc)(RIG*, const struct confparams *, rig_ptr_t), rig_ptr_t data));
 extern HAMLIB_EXPORT(const struct confparams*) rig_ext_lookup HAMLIB_PARAMS((RIG *rig, const char *name));
+extern HAMLIB_EXPORT(const struct confparams *)  rig_ext_lookup_tok HAMLIB_PARAMS((RIG *rig, token_t token));
 extern HAMLIB_EXPORT(token_t) rig_ext_token_lookup HAMLIB_PARAMS((RIG *rig, const char *name));
 
 
@@ -1618,3 +1642,5 @@ extern HAMLIB_EXPORT(rptr_shift_t) rig_parse_rptr_shift(const char *s);
 __END_DECLS
 
 #endif /* _RIG_H */
+
+/*! @} */
