@@ -2,7 +2,7 @@
  *  Hamlib Kenwood backend - main file
  *  Copyright (c) 2000-2005 by Stephane Fillod and others
  *
- *	$Id: kenwood.c,v 1.89 2005/09/28 21:14:44 fillods Exp $
+ *	$Id: kenwood.c,v 1.93 2006/04/10 18:00:38 pa4tu Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -104,7 +104,7 @@ static const struct kenwood_id_string kenwood_id_string_list[] = {
 /*
  * 38 CTCSS sub-audible tones
   */
-const int kenwood38_ctcss_list[] = {
+const tone_t kenwood38_ctcss_list[] = {
 	 670,  719,  744,  770,  797,  825,  854,  885,  915,  948,
 	 974, 1000, 1035, 1072, 1109, 1148, 1188, 1230, 1273, 1318,
 	1365, 1413, 1462, 1514, 1567, 1622, 1679, 1738, 1799, 1862,
@@ -167,7 +167,6 @@ transaction_write:
         return RIG_OK;  /* don't want a reply */
     }
 
-transaction_read:
     memset(data,0,*datasize);
     retval = read_string(&rs->rigport, data, *datasize, cmdtrm, strlen(cmdtrm));
     if (retval < 0) {
@@ -238,8 +237,9 @@ transaction_quit:
  */
 int kenwood_set_vfo(RIG *rig, vfo_t vfo)
 {
-	unsigned char cmdbuf[16], ackbuf[16];
-	int cmd_len, ack_len, retval;
+	char cmdbuf[16], ackbuf[50];
+	int cmd_len, retval;
+	size_t ack_len;
 	char vfo_function;
 
 	switch (vfo) {
@@ -263,6 +263,7 @@ int kenwood_set_vfo(RIG *rig, vfo_t vfo)
 		return retval;
 
 	/* set TX VFO */
+	ack_len = 0;
 	cmdbuf[1] = 'T';
 	ack_len = 0;
 	retval = kenwood_transaction (rig, cmdbuf, 4, ackbuf, &ack_len);
@@ -272,9 +273,10 @@ int kenwood_set_vfo(RIG *rig, vfo_t vfo)
 
 int kenwood_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
 {
-	unsigned char cmdbuf[16], ackbuf[16];
-	int cmd_len, ack_len, retval;
-	char vfo_function;
+	char cmdbuf[16], ackbuf[50];
+	int cmd_len, retval;
+	size_t ack_len;
+	unsigned char vfo_function;
 
 	if(vfo !=RIG_VFO_CURR) {
 	switch (vfo) {
@@ -325,8 +327,9 @@ int kenwood_set_split_vfo(RIG *rig, vfo_t vfo, split_t split, vfo_t txvfo)
  */
 int kenwood_get_vfo(RIG *rig, vfo_t *vfo)
 {
-	unsigned char infobuf[50];
-	int info_len, retval;
+	char infobuf[50];
+	int retval;
+	size_t info_len;
 
 	info_len = 50;
 	retval = kenwood_transaction (rig, "IF;", 3, infobuf, &info_len);
@@ -357,10 +360,11 @@ int kenwood_get_vfo(RIG *rig, vfo_t *vfo)
  */
 int kenwood_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 {
-	unsigned char freqbuf[16], ackbuf[16];
-	int freq_len, ack_len, retval;
-	char vfo_letter;
-	vfo_t	tvfo;
+	char freqbuf[16], ackbuf[50];
+	int freq_len, retval;
+	size_t ack_len;
+	unsigned char vfo_letter;
+	vfo_t tvfo;
 
 	tvfo = vfo==RIG_VFO_CURR ? rig->state.current_vfo : vfo;
                                                                                          
@@ -373,7 +377,7 @@ int kenwood_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
 							vfo);
 		return -RIG_EINVAL;
 	}
-	freq_len = sprintf(freqbuf,"F%c%011"PRIll";", vfo_letter, (long long)freq);
+	freq_len = sprintf(freqbuf,"F%c%011ld;", vfo_letter, (long)freq);
 
 	ack_len = 0;
 	retval = kenwood_transaction (rig, freqbuf, freq_len, ackbuf, &ack_len);
@@ -387,11 +391,12 @@ int kenwood_set_freq(RIG *rig, vfo_t vfo, freq_t freq)
  */
 int kenwood_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 {
-	unsigned char freqbuf[50];
-	unsigned char cmdbuf[4];
-	int cmd_len, freq_len, retval;
-	char vfo_letter;
-	vfo_t	tvfo;
+	char freqbuf[50];
+	char cmdbuf[4];
+	int cmd_len, retval;
+	size_t freq_len;
+	unsigned char vfo_letter;
+	vfo_t tvfo;
 
 	tvfo = vfo==RIG_VFO_CURR ? rig->state.current_vfo : vfo;
                                                                                          
@@ -425,8 +430,9 @@ int kenwood_get_freq(RIG *rig, vfo_t vfo, freq_t *freq)
 
 int kenwood_get_rit(RIG *rig, vfo_t vfo, shortfreq_t * rit)
 {
-	unsigned char infobuf[50];
-	int info_len, retval;
+	char infobuf[50];
+	int retval;
+	size_t info_len;
 
 	info_len = 50;
 	retval = kenwood_transaction (rig, "IF;", 3, infobuf, &info_len);
@@ -450,9 +456,10 @@ int kenwood_get_rit(RIG *rig, vfo_t vfo, shortfreq_t * rit)
  */
 int kenwood_set_rit(RIG * rig, vfo_t vfo, shortfreq_t rit)
 {
-        unsigned char buf[50], infobuf[50], c;
-        int retval, info_len, len, i;
-
+        char buf[50], infobuf[50];
+	unsigned char c;
+        int retval, len, i;
+	size_t info_len;
 	
 	info_len = 0;
         if (rit == 0)
@@ -490,9 +497,10 @@ int kenwood_set_xit(RIG * rig, vfo_t vfo, shortfreq_t rit)
 
 int kenwood_scan(RIG * rig, vfo_t vfo, scan_t scan, int ch)
 {
-	unsigned char ackbuf[16];
-	int ack_len = 0;
+	char ackbuf[50];
+	size_t ack_len;
 
+	ack_len = 0;
 	return kenwood_transaction (rig, scan==RIG_SCAN_STOP? "SC0;":"SC1;", 4, 
 						ackbuf, &ack_len);
 }
@@ -504,8 +512,9 @@ int kenwood_scan(RIG * rig, vfo_t vfo, scan_t scan, int ch)
  */
 int kenwood_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
 {
-	unsigned char mdbuf[16],ackbuf[16];
-	int mdbuf_len, ack_len, kmode, retval;
+	char mdbuf[16], ackbuf[50];
+	int mdbuf_len, kmode, retval;
+	size_t ack_len;
 
 	switch (mode) {
 		case RIG_MODE_CW:       kmode = MD_CW; break;
@@ -535,9 +544,9 @@ int kenwood_set_mode(RIG *rig, vfo_t vfo, rmode_t mode, pbwidth_t width)
  */
 int kenwood_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 {
-	unsigned char modebuf[50];
-	int mode_len, retval;
-
+	char modebuf[50];
+	int retval;
+	size_t mode_len;
 
 	mode_len = 50;
 	retval = kenwood_transaction (rig, "MD;", 3, modebuf, &mode_len);
@@ -573,9 +582,10 @@ int kenwood_get_mode(RIG *rig, vfo_t vfo, rmode_t *mode, pbwidth_t *width)
 
 int kenwood_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
 {
-	unsigned char levelbuf[16], ackbuf[16];
-	int level_len, ack_len, retval;
+	char levelbuf[16], ackbuf[50];
+	int level_len, retval;
 	int i, kenwood_val;
+	size_t ack_len;
 
 	if (RIG_LEVEL_IS_FLOAT(level))
 		kenwood_val = val.f * 255;
@@ -635,9 +645,10 @@ int kenwood_set_level(RIG *rig, vfo_t vfo, setting_t level, value_t val)
  */
 int get_kenwood_level(RIG *rig, const char *cmd, int cmd_len, float *f)
 {
-	unsigned char lvlbuf[50];
-	int lvl_len, retval;
+	char lvlbuf[50];
+	int retval;
 	int lvl;
+	size_t lvl_len;
 
 	lvl_len = 50;
 	retval = kenwood_transaction (rig, cmd, cmd_len, lvlbuf, &lvl_len);
@@ -666,10 +677,11 @@ int get_kenwood_level(RIG *rig, const char *cmd, int cmd_len, float *f)
  */
 int kenwood_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 {
-	unsigned char lvlbuf[50];
-	int lvl_len, retval;
+	char lvlbuf[50];
+	int retval;
 	int lvl;
 	int i, ret, agclevel;
+	size_t lvl_len;
 
 	lvl_len = 50;
 	switch (level) {
@@ -768,8 +780,9 @@ int kenwood_get_level(RIG *rig, vfo_t vfo, setting_t level, value_t *val)
 
 int kenwood_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 {
-	unsigned char fctbuf[16], ackbuf[16];
-	int fct_len, ack_len;
+	char fctbuf[16], ackbuf[50];
+	int fct_len;
+	size_t ack_len;
 
 	/* Optimize:
 	 *   sort the switch cases with the most frequent first
@@ -817,8 +830,8 @@ int kenwood_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
 		return kenwood_transaction (rig, fctbuf, fct_len, ackbuf, &ack_len);
 
 	case RIG_FUNC_LOCK:
-	fct_len = sprintf(fctbuf,"LK%c;", (0==status)?'0':'1');
-	return kenwood_transaction (rig, fctbuf, fct_len, ackbuf, &ack_len);
+		fct_len = sprintf(fctbuf,"LK%c;", (0==status)?'0':'1');
+		return kenwood_transaction (rig, fctbuf, fct_len, ackbuf, &ack_len);
 
 	default:
 		rig_debug(RIG_DEBUG_ERR,"Unsupported set_func %#x", func);
@@ -835,8 +848,9 @@ int kenwood_set_func(RIG *rig, vfo_t vfo, setting_t func, int status)
  */
 static int get_kenwood_func(RIG *rig, const char *cmd, int cmd_len, int *status)
 {
-	unsigned char fctbuf[50];
-	int fct_len, retval;
+	char fctbuf[50];
+	int retval;
+	size_t fct_len;
 
 	fct_len = 50;
 	retval = kenwood_transaction (rig, cmd, cmd_len, fctbuf, &fct_len);
@@ -861,11 +875,11 @@ static int get_kenwood_func(RIG *rig, const char *cmd, int cmd_len, int *status)
  */
 int kenwood_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 {
-	unsigned char fctbuf[50];
-	int fct_len, retval;
+	char fctbuf[50];
+	int retval;
+	size_t fct_len;
 
 	fct_len = 50;
-
 	switch (func) {
 	case RIG_FUNC_FAGC:
 		retval = kenwood_transaction (rig, "GT;", 3, fctbuf, &fct_len);
@@ -932,10 +946,11 @@ int kenwood_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
 int kenwood_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 {
 	const struct rig_caps *caps;
-	unsigned char tonebuf[16], ackbuf[16];
-	int tone_len, ack_len;
+	char tonebuf[16], ackbuf[50];
+	int tone_len;
 	int i;
-								 
+	size_t ack_len;
+
 	caps = rig->caps;
 
 /* TODO: replace 200 by something like RIGTONEMAX */
@@ -960,10 +975,11 @@ int kenwood_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 int kenwood_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 {
 	const struct rig_caps *caps;
-	unsigned char tonebuf[50];
-	int tone_len, i, retval;
+	char tonebuf[50];
+	int i, retval;
 	unsigned int tone_idx;
-								 
+	size_t tone_len;
+						 
 	caps = rig->caps;
 
 	tone_len = 50;
@@ -1005,8 +1021,9 @@ int kenwood_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
  */
 int kenwood_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
 {
-	unsigned char infobuf[50];
-	int info_len, retval;
+	char infobuf[50];
+	int retval;
+	size_t info_len;
 
 	info_len = 50;
 	retval = kenwood_transaction (rig, "IF;", 3, infobuf, &info_len);
@@ -1031,9 +1048,10 @@ int kenwood_get_ptt(RIG *rig, vfo_t vfo, ptt_t *ptt)
  */
 int kenwood_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
 {
-	unsigned char ackbuf[16];
-	int ack_len = 0;
+	char ackbuf[50];
+	size_t ack_len;
 
+	ack_len = 0;
 	return kenwood_transaction (rig, ptt==RIG_PTT_ON? "TX;":"RX;", 3, 
 					ackbuf, &ack_len);
 }
@@ -1045,8 +1063,9 @@ int kenwood_set_ptt(RIG *rig, vfo_t vfo, ptt_t ptt)
  */
 int kenwood_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 {
-	unsigned char busybuf[50];
-	int busy_len, retval;
+	char busybuf[50];
+	int retval;
+	size_t busy_len;
 								 
 	busy_len = 50;
 	retval = kenwood_transaction (rig, "BY;", 3, busybuf, &busy_len);
@@ -1070,11 +1089,13 @@ int kenwood_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
  */
 int kenwood_set_trn(RIG *rig, int trn)
 {
-	unsigned char trnbuf[16], ackbuf[16];
-	int trn_len, ack_len = 0;
+	char trnbuf[16], ackbuf[50];
+	int trn_len;
+	size_t ack_len;
 
 	trn_len = sprintf(trnbuf,"AI%c;", trn==RIG_TRN_RIG?'1':'0');
 
+	ack_len = 0;
 	return kenwood_transaction (rig, trnbuf, trn_len, ackbuf, &ack_len);
 }
 
@@ -1084,8 +1105,9 @@ int kenwood_set_trn(RIG *rig, int trn)
  */
 int kenwood_get_trn(RIG *rig, int *trn)
 {
-	unsigned char trnbuf[50];
-	int trn_len, retval;
+	char trnbuf[50];
+	int retval;
+	size_t trn_len;
 
 	trn_len = 50;
 	retval = kenwood_transaction (rig, "AI;", 3, trnbuf, &trn_len);
@@ -1108,11 +1130,13 @@ int kenwood_get_trn(RIG *rig, int *trn)
  */
 int kenwood_set_powerstat(RIG *rig, powerstat_t status)
 {
-	unsigned char pwrbuf[16], ackbuf[16];
-	int pwr_len, ack_len = 0;
+	char pwrbuf[16], ackbuf[50];
+	int pwr_len;
+	size_t ack_len;
 
 	pwr_len = sprintf(pwrbuf,"PS%c;", status==RIG_POWER_ON?'1':'0');
 
+	ack_len = 0;
 	return kenwood_transaction (rig, pwrbuf, pwr_len, ackbuf, &ack_len);
 }
 
@@ -1122,9 +1146,11 @@ int kenwood_set_powerstat(RIG *rig, powerstat_t status)
  */
 int kenwood_get_powerstat(RIG *rig, powerstat_t *status)
 {
-	unsigned char pwrbuf[50];
-	int pwr_len = 50, retval;
+	char pwrbuf[50];
+	int retval;
+	size_t pwr_len;
 
+	pwr_len = 50;
 	retval = kenwood_transaction (rig, "PS;", 3, pwrbuf, &pwr_len);
 	if (retval != RIG_OK)
 		return retval;
@@ -1145,9 +1171,10 @@ int kenwood_get_powerstat(RIG *rig, powerstat_t *status)
  */
 int kenwood_reset(RIG *rig, reset_t reset)
 {
-	unsigned char rstbuf[16], ackbuf[16];
-	int rst_len, ack_len = 0;
+	char rstbuf[16], ackbuf[50];
+	int rst_len;
 	char rst;
+	size_t ack_len;
 
 	switch(reset) {
 		case RIG_RESET_VFO: rst='1'; break;
@@ -1159,6 +1186,7 @@ int kenwood_reset(RIG *rig, reset_t reset)
 	}
 	rst_len = sprintf(rstbuf,"SR%c;", rst);
 
+	ack_len = 0;
 	return kenwood_transaction (rig, rstbuf, rst_len, ackbuf, &ack_len);
 }
 
@@ -1168,10 +1196,11 @@ int kenwood_reset(RIG *rig, reset_t reset)
  */
 int kenwood_send_morse(RIG *rig, vfo_t vfo, const char *msg)
 {
-	unsigned char morsebuf[30], m2[30], ackbuf[16];
-	int morse_len, ack_len;
+	char morsebuf[30], m2[30], ackbuf[50];
+	int morse_len;
 	int msg_len, buff_len, retval;
 	const char *p;
+	size_t ack_len;
 
 	p = msg;
 	msg_len = strlen(msg);
@@ -1211,8 +1240,8 @@ int kenwood_send_morse(RIG *rig, vfo_t vfo, const char *msg)
  */
 int kenwood_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 {
-	unsigned char *cmd, ackbuf[16];
-	int ack_len = 0;
+	char *cmd, ackbuf[50];
+	size_t ack_len;
 
 	switch(op) {
 		case RIG_OP_UP: cmd="UP;"; break;
@@ -1224,8 +1253,7 @@ int kenwood_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
 							op);
 			return -RIG_EINVAL;
 	}
-
-	ack_len = 16;
+	ack_len = 0;
 	return kenwood_transaction (rig, cmd, 3, ackbuf, &ack_len);
 }
 
@@ -1235,8 +1263,9 @@ int kenwood_vfo_op(RIG *rig, vfo_t vfo, vfo_op_t op)
  */
 int kenwood_set_mem(RIG *rig, vfo_t vfo, int ch)
 {
-	unsigned char membuf[16], ackbuf[16];
-	int mem_len, ack_len = 0;
+	char membuf[16], ackbuf[16];
+	int mem_len;
+	size_t ack_len;
 
 	/*
 	 * "MCbmm;"
@@ -1245,6 +1274,7 @@ int kenwood_set_mem(RIG *rig, vfo_t vfo, int ch)
 	 */
 	mem_len = sprintf(membuf, "MC %02d;", ch);
 
+	ack_len = 0;
 	return kenwood_transaction (rig, membuf, mem_len, ackbuf, &ack_len);
 }
 
@@ -1254,8 +1284,9 @@ int kenwood_set_mem(RIG *rig, vfo_t vfo, int ch)
  */
 int kenwood_get_mem(RIG *rig, vfo_t vfo, int *ch)
 {
-	unsigned char membuf[50];
-	int retval, mem_len;
+	char membuf[50];
+	int retval;
+	size_t mem_len;
 
 	/*
 	 * "MCbmm;"
@@ -1285,9 +1316,10 @@ int kenwood_get_mem(RIG *rig, vfo_t vfo, int *ch)
  */
 const char* kenwood_get_info(RIG *rig)
 {
-	unsigned char firmbuf[50];
-	int firm_len, retval;
-								 
+	char firmbuf[50];
+	int retval;
+	size_t firm_len;
+
 	firm_len = 50;
 	retval = kenwood_transaction (rig, "TY;", 3, firmbuf, &firm_len);
 	if (retval != RIG_OK)
@@ -1319,7 +1351,7 @@ const char* kenwood_get_info(RIG *rig)
  */
 DECLARE_PROBERIG_BACKEND(kenwood)
 {
-	unsigned char idbuf[IDBUFSZ];
+	char idbuf[IDBUFSZ];
 	int id_len=-1, i, k_id;
 	int retval=-1;
 	int rates[] = { 115200, 57600, 9600, 4800, 1200, 0 };	/* possible baud rates */
