@@ -1,6 +1,10 @@
+/**
+ * \addtogroup rig
+ * @{
+ */
+
 /**
  * \file src/conf.c
- * \ingroup rig
  * \brief Rig configuration interface
  * \author Stephane Fillod
  * \date 2000-2006
@@ -9,7 +13,7 @@
  *  Hamlib Interface - configuration interface
  *  Copyright (c) 2000-2006 by Stephane Fillod
  *
- *	$Id: conf.c,v 1.14 2006/02/26 19:29:19 fillods Exp $
+ *	$Id: conf.c,v 1.15 2006/10/15 00:27:51 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -457,3 +461,4 @@ int HAMLIB_API rig_get_conf(RIG *rig, token_t token, char *val)
 	return rig->caps->get_conf(rig, token, val);
 }
 
+/*! @} */
