@@ -2,7 +2,7 @@
  *  Hamlib Interface - generic file based io functions
  *  Copyright (c) 2000-2004 by Stephane Fillod and Frank Singleton
  *
- *	$Id: iofunc.c,v 1.13 2004/10/02 10:32:08 fillods Exp $
+ *	$Id: iofunc.c,v 1.16 2006/10/15 00:27:51 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -20,6 +20,16 @@
  *
  */
 
+/**
+ * \file iofunc.c
+ * \brief Generic file-based IO functions
+ */
+
+/**
+ * \addtogroup rig_internal
+ * @{
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -45,8 +55,14 @@
 #define select win32_serial_select
 #endif
 
-/*
- * Write a block of count characters to file descriptor,
+/**
+ * \brief Write a block of characters to an fd.
+ * \param p rig port descriptor
+ * \param txbuffer command sequence to be sent
+ * \param count number of bytes to send
+ * \return 0 = OK, <0 = NOK
+ *
+ * Write a block of count characters to port file descriptor,
  * with a pause between each character if write_delay is > 0
  *
  * The write_delay is for Yaesu type rigs..require 5 character
@@ -55,8 +71,6 @@
  * Also, post_write_delay is for some Yaesu rigs (eg: FT747) that
  * get confused with sequential fast writes between cmd sequences.
  *
- *
- *
  * input:
  *
  * fd - file descriptor to write to
@@ -66,16 +80,11 @@
  * post_write_delay - minimum delay between two writes
  * post_write_date - timeval of last write
  *
- * returns:
- *
- *  0 = OK
- *  <0 = NOT OK
- *
  * Actually, this function has nothing specific to serial comm,
  * it could work very well also with any file handle, like a socket.
  */
 
-int HAMLIB_API write_block(port_t *p, const char *txbuffer, size_t count)
+int HAMLIB_API write_block(hamlib_port_t *p, const char *txbuffer, size_t count)
 {
   int i;
 
@@ -129,13 +138,19 @@ int HAMLIB_API write_block(port_t *p, const char *txbuffer, size_t count)
 				   /* with sequential fast writes*/
   }
   rig_debug(RIG_DEBUG_TRACE,"TX %d bytes\n",count);
-  dump_hex(txbuffer,count);
+  dump_hex((unsigned char *) txbuffer,count);
   
   return RIG_OK;
 }
 
 
-/*
+/**
+ * \brief Read bytes from an fd
+ * \param p rig port descriptor
+ * \param rxbuffer buffer to receive text
+ * \param count number of bytes
+ * \return count of bytes received
+ *
  * Read "num" bytes from "fd" and put results into
  * an array of unsigned char pointed to by "rxbuffer"
  * 
@@ -147,7 +162,7 @@ int HAMLIB_API write_block(port_t *p, const char *txbuffer, size_t count)
  * it could work very well also with any file handle, like a socket.
  */
 
-int HAMLIB_API read_block(port_t *p, char *rxbuffer, size_t count)
+int HAMLIB_API read_block(hamlib_port_t *p, char *rxbuffer, size_t count)
 {  
   fd_set rfds;
   struct timeval tv, tv_timeout;
@@ -168,13 +183,13 @@ int HAMLIB_API read_block(port_t *p, char *rxbuffer, size_t count)
 
 		retval = select(p->fd+1, &rfds, NULL, NULL, &tv);
 		if (retval == 0) {
-			dump_hex(rxbuffer, total_count);
+			dump_hex((unsigned char *) rxbuffer, total_count);
 			rig_debug(RIG_DEBUG_WARN, "read_block: timedout after %d chars\n",
 							total_count);
 				return -RIG_ETIMEOUT;
 		}
 		if (retval < 0) {
-			dump_hex(rxbuffer, total_count);
+			dump_hex((unsigned char *) rxbuffer, total_count);
 			rig_debug(RIG_DEBUG_ERR,"read_block: select error after %d chars: "
 							"%s\n", total_count, strerror(errno));
 				return -RIG_EIO;
@@ -195,12 +210,19 @@ int HAMLIB_API read_block(port_t *p, char *rxbuffer, size_t count)
   }
 
   rig_debug(RIG_DEBUG_TRACE,"RX %d bytes\n",total_count);
-  dump_hex(rxbuffer, total_count);
+  dump_hex((unsigned char *) rxbuffer, total_count);
   return total_count;			/* return bytes count read */
 }
 
 
-/*
+/**
+ * \brief Read a string from an fd
+ * \param p Hamlib port descriptor
+ * \param rxbuffer buffer to receive string
+ * \param rxmax maximum string size + 1
+ * \param stopset string of recognized end of string characters
+ * \param stopset_len length of stopset
+ *
  * Read a string from "fd" and put result into
  * an array of unsigned char pointed to by "rxbuffer"
  *
@@ -215,7 +237,7 @@ int HAMLIB_API read_block(port_t *p, char *rxbuffer, size_t count)
  *
  * Assumes rxbuffer!=NULL
  */
-int HAMLIB_API read_string(port_t *p, char *rxbuffer, size_t rxmax, const char *stopset,
+int HAMLIB_API read_string(hamlib_port_t *p, char *rxbuffer, size_t rxmax, const char *stopset,
 				int stopset_len)
 {
   fd_set rfds;
@@ -240,9 +262,9 @@ int HAMLIB_API read_string(port_t *p, char *rxbuffer, size_t rxmax, const char *
             break;
 
 		if (retval < 0) {
-			dump_hex(rxbuffer, total_count);
-            rig_debug(RIG_DEBUG_ERR, "%s: select error after %d chars: %s\n", 
-				__FUNCTION__, total_count, strerror(errno));
+			dump_hex((unsigned char *) rxbuffer, total_count);
+                        rig_debug(RIG_DEBUG_ERR, "%s: select error after %d chars: %s\n", 
+                                  __FUNCTION__, total_count, strerror(errno));
             return -RIG_EIO;
 		}
 		/*
@@ -251,7 +273,7 @@ int HAMLIB_API read_string(port_t *p, char *rxbuffer, size_t rxmax, const char *
 		 */
         rd_count = read(p->fd, &rxbuffer[total_count], 1);
 		if (rd_count < 0) {
-			dump_hex(rxbuffer, total_count);
+			dump_hex((unsigned char *) rxbuffer, total_count);
             rig_debug(RIG_DEBUG_ERR, "%s: read failed - %s\n",__FUNCTION__,
                             strerror(errno));
             return -RIG_EIO;
@@ -273,7 +295,8 @@ int HAMLIB_API read_string(port_t *p, char *rxbuffer, size_t rxmax, const char *
   }
 
   rig_debug(RIG_DEBUG_TRACE,"RX %d characters\n",total_count);
-  dump_hex(rxbuffer, total_count);
+  dump_hex((unsigned char *) rxbuffer, total_count);
   return total_count;			/* return bytes count read */
 }
 
+/** @} */
