@@ -1,18 +1,22 @@
+/** \addtogroup rig
+ * @{
+ */
+
 /**
  * \file src/mem.c
- * \ingroup rig
  * \brief Memory and channel interface
  * \author Stephane Fillod
  * \date 2000-2006
  *
  * Hamlib interface is a frontend implementing wrapper functions.
+ * 
  */
 
 /*
  *  Hamlib Interface - mem/channel calls
  *  Copyright (c) 2000-2006 by Stephane Fillod
  *
- *	$Id: mem.c,v 1.7 2006/01/15 14:25:25 fillods Exp $
+ *	$Id: mem.c,v 1.11 2006/10/15 00:27:51 aa6e Exp $
  *
  *   This library is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License as
@@ -662,7 +666,7 @@ int HAMLIB_API rig_set_chan_all_cb (RIG *rig, chan_cb_t chan_cb, rig_ptr_t arg)
  *
  *  Retrieves the data associated with a all the memory channels.
  *
- *  \a chan_cb is called first with no data in \chan (chan equals NULL). 
+ *  \a chan_cb is called first with no data in chan (chan equals NULL). 
  *  This means the application has to provide a struct where to store 
  *  future data for channel channel_num. If channel_num == chan->channel_num,
  *  the application does not need to provide a new allocated structure.
@@ -697,7 +701,7 @@ int HAMLIB_API rig_get_chan_all_cb (RIG *rig, chan_cb_t chan_cb, rig_ptr_t arg)
 /**
  * \brief set all channel data
  * \param rig	The rig handle
- * \param chan	The location of data to set for all channels
+ * \param chans	The location of data to set for all channels
  *
  * Write the data associated with all the memory channels.
  *
@@ -717,7 +721,7 @@ int HAMLIB_API rig_set_chan_all (RIG *rig, const channel_t chans[])
 		return -RIG_EINVAL;
 
 	rc = rig->caps;
-	map_arg.chans = chans;
+	map_arg.chans = (channel_t *) chans;
 
 	if (rc->set_chan_all_cb)
 		return rc->set_chan_all_cb(rig, map_chan, (rig_ptr_t)&map_arg);
@@ -733,7 +737,7 @@ int HAMLIB_API rig_set_chan_all (RIG *rig, const channel_t chans[])
 /**
  * \brief get all channel data
  * \param rig	The rig handle
- * \param chan	The location where to store all the channel data
+ * \param chans	The location where to store all the channel data
  *
  * Retrieves the data associated with all the memory channels.
  *
@@ -813,7 +817,7 @@ int set_parm_all_cb_generic (RIG *rig, confval_cb_t parm_cb, rig_ptr_t cfgps,
  * \sa rig_get_mem_all_cb(), rig_set_mem_all()
  * \todo finish coding and testing of mem_all functions
  */
-int rig_set_mem_all_cb (RIG *rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_ptr_t arg)
+int HAMLIB_API rig_set_mem_all_cb (RIG *rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_ptr_t arg)
 {
 	struct rig_caps *rc;
 	int retval;
@@ -862,7 +866,7 @@ int rig_set_mem_all_cb (RIG *rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_p
  * \todo get all parm's
  * \todo finish coding and testing of mem_all functions
  */
-int rig_get_mem_all_cb (RIG *rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_ptr_t arg)
+int HAMLIB_API rig_get_mem_all_cb (RIG *rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_ptr_t arg)
 {
 	struct rig_caps *rc;
 	int retval;
@@ -895,9 +899,9 @@ int rig_get_mem_all_cb (RIG *rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_p
 /**
  * \brief set all channel and non-channel data
  * \param rig	The rig handle
- * \param chan_cb	The callback for channel data
- * \param parm_cb	The callback for non-channel(aka parm) data
- * \param arg	Cookie passed to \a chan_cb and \a parm_cb
+ * \param chans	Channel data
+ * \param cfgps	??
+ * \param vals	??
  *
  * Writes the data associated with all the memory channels,
  * and rigs memory parameters.
@@ -911,7 +915,7 @@ int rig_get_mem_all_cb (RIG *rig, chan_cb_t chan_cb, confval_cb_t parm_cb, rig_p
  * \todo set all parm's
  * \todo finish coding and testing of mem_all functions
  */
-int rig_set_mem_all (RIG *rig, const channel_t chans[], const struct confparams cfgps[], const value_t vals[])
+int HAMLIB_API rig_set_mem_all (RIG *rig, const channel_t chans[], const struct confparams cfgps[], const value_t vals[])
 {
 	struct rig_caps *rc;
 	int retval;
@@ -921,9 +925,9 @@ int rig_set_mem_all (RIG *rig, const channel_t chans[], const struct confparams
 		return -RIG_EINVAL;
 
 	rc = rig->caps;
-	mem_all_arg.chans = chans;
+	mem_all_arg.chans = (channel_t *) chans;
 	mem_all_arg.cfgps = cfgps;
-	mem_all_arg.vals = vals;
+	mem_all_arg.vals = (value_t *) vals;
 
 	if (rc->set_mem_all_cb)
 		return rc->set_mem_all_cb(rig, map_chan, map_parm,
@@ -962,7 +966,7 @@ int rig_set_mem_all (RIG *rig, const channel_t chans[], const struct confparams
  * \sa rig_get_mem_all(), rig_set_mem_all_cb()
  * \todo finish coding and testing of mem_all functions
  */
-int rig_get_mem_all (RIG *rig, channel_t chans[], const struct confparams cfgps[], value_t vals[])
+int HAMLIB_API rig_get_mem_all (RIG *rig, channel_t chans[], const struct confparams cfgps[], value_t vals[])
 {
 	struct rig_caps *rc;
 	int retval;
@@ -995,3 +999,4 @@ int rig_get_mem_all (RIG *rig, channel_t chans[], const struct confparams cfgps[
 	return retval;
 }
 
+/*! @} */
