@@ -4,7 +4,7 @@
  * The code is rather ugly since this is only a try out.
  *
  *
- *    $Id: rigmatrix.c,v 1.17 2002/01/29 22:05:37 fillods Exp $  
+ *    $Id: rigmatrix.c,v 1.21 2006/09/22 14:31:19 n0nb Exp $  
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -46,7 +46,7 @@ int print_caps_sum(const struct rig_caps *caps, void *data)
 					"<TD>%s</TD><TD>%s</TD><TD>",
 					caps->rig_model,
 					caps->model_name,caps->mfg_name,caps->version,
-					strstatus(caps->status)
+					rig_strstatus(caps->status)
 					);
 
 	switch (caps->rig_type & RIG_TYPE_MASK) {
@@ -212,8 +212,8 @@ int print_caps_caps(const struct rig_caps *caps, void *data)
 	print_yn(caps->get_rptr_offs);
 	print_yn(caps->set_split_freq);
 	print_yn(caps->get_split_freq);
-	print_yn(caps->set_split);
-	print_yn(caps->get_split);
+	print_yn(caps->set_split_vfo);
+	print_yn(caps->get_split_vfo);
 	print_yn(caps->set_ts);
 	print_yn(caps->get_ts);
 	print_yn(caps->set_ctcss_tone);
@@ -253,7 +253,7 @@ int print_caps_parm(const struct rig_caps *caps, void *data)
 	/*
 	 * bitmap_parm: only those who have a label
 	 */
-	for (i = 0; i < 60; i++) {
+	for (i = 0; i < RIG_SETTING_MAX; i++) {
 			if (rig_idx2setting(i) & bitmap_parm)
 					print_yn(parm & rig_idx2setting(i));
 	}
@@ -283,7 +283,7 @@ int print_caps_level(const struct rig_caps *caps, void *data)
 	/*
 	 * bitmap_level: only those who have a label
 	 */
-	for (i = 0; i < 60; i++) {
+	for (i = 0; i < 32; i++) {
 			if (rig_idx2setting(i) & bitmap_level)
 					print_yn(level & rig_idx2setting(i));
 	}
@@ -313,7 +313,7 @@ int print_caps_func(const struct rig_caps *caps, void *data)
 	/*
 	 * bitmap_func: only those who have a label
 	 */
-	for (i = 0; i < 60; i++) {
+	for (i = 0; i < RIG_SETTING_MAX; i++) {
 			if (rig_idx2setting(i) & bitmap_func)
 					print_yn(func & rig_idx2setting(i));
 	}
@@ -554,9 +554,9 @@ int main (int argc, char *argv[])
 	bitmap_func = 0;
 	prntbuf[0] = '\0';
 	pbuf = prntbuf;
-	for (i = 0; i < 60; i++) {
+	for (i = 0; i < RIG_SETTING_MAX; i++) {
 			setting_t func = rig_idx2setting(i);
-			const char *s = strfunc(func);
+			const char *s = rig_strfunc(func);
 			if (!s)
 					continue;
 			bitmap_func |= func;
@@ -584,9 +584,9 @@ int main (int argc, char *argv[])
 	bitmap_level = 0;
 	prntbuf[0] = '\0';
 	pbuf = prntbuf;
-	for (i = 0; i < 60; i++) {
+	for (i = 0; i < RIG_SETTING_MAX; i++) {
 			setting_t level = rig_idx2setting(i);
-			const char *s = strlevel(level);
+			const char *s = rig_strlevel(level);
 			if (!s)
 					continue;
 			bitmap_level |= level;
@@ -614,9 +614,9 @@ int main (int argc, char *argv[])
 	bitmap_parm = 0;
 	prntbuf[0] = '\0';
 	pbuf = prntbuf;
-	for (i = 0; i < 60; i++) {
+	for (i = 0; i < RIG_SETTING_MAX; i++) {
 			setting_t parm = rig_idx2setting(i);
-			const char *s = strparm(parm);
+			const char *s = rig_strparm(parm);
 			if (!s)
 					continue;
 			bitmap_parm |= parm;
