@@ -11,7 +11,7 @@
  * copied back and adopted for the FT-817.
  *
  *
- *    $Id: ft817.c,v 1.12 2005/09/04 10:44:22 csete Exp $  
+ *    $Id: ft817.c,v 1.14 2006/10/07 15:51:38 csete Exp $  
  *
  *
  *  This library is free software; you can redistribute it and/or
@@ -149,7 +149,7 @@ const struct rig_caps ft817_caps = {
 	.rig_model = 		RIG_MODEL_FT817,
 	.model_name = 	        "FT-817", 
 	.mfg_name = 		"Yaesu", 
-	.version = 		"0.2", 
+	.version = 		"0.3", 
 	.copyright = 		"LGPL",
 	.status = 		RIG_STATUS_BETA,
 	.rig_type = 		RIG_TYPE_TRANSCEIVER,
@@ -440,9 +440,9 @@ static int ft817_get_status(RIG *rig, int status)
 
 	serial_flush(&rig->state.rigport);
 
-	write_block(&rig->state.rigport, p->pcs[status].nseq, YAESU_CMD_LENGTH);
+	write_block(&rig->state.rigport, (char *) p->pcs[status].nseq, YAESU_CMD_LENGTH);
 
-	if ((n = read_block(&rig->state.rigport, data, len)) < 0)
+	if ((n = read_block(&rig->state.rigport, (char *) data, len)) < 0)
 		return n;
 
 	if (n != len)
@@ -564,9 +564,14 @@ static int ft817_get_pometer_level(RIG *rig, value_t *val)
 		if ((n = ft817_get_status(rig, FT817_NATIVE_CAT_GET_TX_STATUS)) < 0)
 			return n;
 
-	/* Valid only if PTT is on */
+	/* Valid only if PTT is on.
+           FT-817 returns the number of bars in the lowest 4 bits
+           No documentation on how to interpret it but the max number
+           of bars on the display is 10 and I measure 4 watts on 20m 
+           when I read 8 bars, but the scale is not exactly linear.
+        */
 	if ((p->tx_status & 0x80) == 0)
-		val->f = ((p->tx_status & 0x0F) / 15.0);
+		val->f = ((p->tx_status & 0x0F) / 10.0);
 	else
 		val->f = 0.0;
 
@@ -653,7 +658,7 @@ int ft817_get_dcd(RIG *rig, vfo_t vfo, dcd_t *dcd)
 static int ft817_read_ack(RIG *rig)
 {
 #if (FT817_POST_WRITE_DELAY == 0)
-	unsigned char dummy;
+	char dummy;
 	int n;
 
 	if ((n = read_block(&rig->state.rigport, &dummy, 1)) < 0) {
@@ -683,7 +688,7 @@ static int ft817_send_cmd(RIG *rig, int index)
 		return -RIG_EINTERNAL;
 	}
 
-	write_block(&rig->state.rigport, p->pcs[index].nseq, YAESU_CMD_LENGTH);
+	write_block(&rig->state.rigport, (char *) p->pcs[index].nseq, YAESU_CMD_LENGTH);
 	return ft817_read_ack(rig);
 }
 
@@ -703,7 +708,7 @@ static int ft817_send_icmd(RIG *rig, int index, unsigned char *data)
 	cmd[YAESU_CMD_LENGTH - 1] = p->pcs[index].nseq[YAESU_CMD_LENGTH - 1];
 	memcpy(cmd, data, YAESU_CMD_LENGTH - 1);
 
-	write_block(&rig->state.rigport, cmd, YAESU_CMD_LENGTH);
+	write_block(&rig->state.rigport, (char *) cmd, YAESU_CMD_LENGTH);
 	return ft817_read_ack(rig);
 }
 
